@@ -2,7 +2,7 @@ package Term::Table;
 use strict;
 use warnings;
 
-our $VERSION = '0.009'; # TRIAL
+our $VERSION = '0.026'; # TRIAL
 
 use Term::Table::Cell();
 
@@ -11,11 +11,10 @@ use Scalar::Util qw/blessed/;
 use List::Util qw/max sum/;
 use Carp qw/croak carp/;
 
-use Term::Table::HashBase qw/rows _columns collapse max_width mark_tail sanitize show_header auto_columns no_collapse header/;
+use Term::Table::HashBase qw/rows _columns collapse max_width mark_tail sanitize show_header auto_columns no_collapse header allow_overflow pad/;
 
 sub BORDER_SIZE()   { 4 }    # '| ' and ' |' borders
 sub DIV_SIZE()      { 3 }    # ' | ' column delimiter
-sub PAD_SIZE()      { 4 }    # Extra arbitrary padding
 sub CELL_PAD_SIZE() { 2 }    # space on either side of the |
 
 sub init {
@@ -37,6 +36,8 @@ sub init {
         }
     }
 
+    $self->{+PAD} = 4 unless defined $self->{+PAD};
+
     $self->{+COLLAPSE}  = 1 unless defined $self->{+COLLAPSE};
     $self->{+SANITIZE}  = 1 unless defined $self->{+SANITIZE};
     $self->{+MARK_TAIL} = 1 unless defined $self->{+MARK_TAIL};
@@ -98,11 +99,16 @@ sub regen_columns {
         if $self->{+COLLAPSE};
 
     my $current = sum(map {$_->{width}} @$cols);
-    my $border = sum(BORDER_SIZE, PAD_SIZE, DIV_SIZE * @$cols);
+    my $border = sum(BORDER_SIZE, $self->{+PAD}, DIV_SIZE * (@$cols - 1));
     my $total = $current + $border;
 
     if ($total > $self->{+MAX_WIDTH}) {
         my $fair = ($self->{+MAX_WIDTH} - $border) / @$cols;
+        if ($fair < 1) {
+            return $self->{+_COLUMNS} = $cols if $self->{+ALLOW_OVERFLOW};
+            croak "Table is too large ($total including $self->{+PAD} padding) to fit into max-width ($self->{+MAX_WIDTH})";
+        }
+
         my $under = 0;
         my @fix;
         for my $c (@$cols) {
@@ -116,6 +122,10 @@ sub regen_columns {
 
         # Recalculate fairness
         $fair = int(($self->{+MAX_WIDTH} - $border - $under) / @fix);
+        if ($fair < 1) {
+            return $self->{+_COLUMNS} = $cols if $self->{+ALLOW_OVERFLOW};
+            croak "Table is too large ($total including $self->{+PAD} padding) to fit into max-width ($self->{+MAX_WIDTH})";
+        }
 
         # Adjust over-long columns
         $_->{width} = $fair for @fix;
@@ -133,7 +143,7 @@ sub render {
             $cell->reset;
         }
     }
-    my $width = sum(BORDER_SIZE, PAD_SIZE, DIV_SIZE * @$cols, map { $_->{width} } @$cols);
+    my $width = sum(BORDER_SIZE, $self->{+PAD}, DIV_SIZE * @$cols, map { $_->{width} } @$cols);
 
     #<<< NO-TIDY
     my $border   = '+' . join('+', map { '-' x ($_->{width}  + CELL_PAD_SIZE) }      @$cols) . '+';
@@ -217,7 +227,7 @@ sub render {
 
     unless (USE_GCS) {
         for my $row (@out) {
-            next unless $row =~ m/[^\x00-\x7F]/;
+            next unless $row =~ m/[[:^ascii:]]/;
             unshift @out => "Unicode::GCString is not installed, table may not display all unicode characters properly";
             last;
         }
@@ -252,19 +262,22 @@ Term::Table - Format a header and rows into a table
 =head1 DESCRIPTION
 
 This is used by some failing tests to provide diagnostics about what has gone
-wrong. This module is able to generic format rows of data into tables.
+wrong. This module is able to format rows of data into tables.
 
 =head1 SYNOPSIS
 
     use Term::Table;
 
     my $table = Term::Table->new(
-        max_width    => 80, # defaults to terminal size 
-        collapse     => 1, # do not show empty columns
-        header => [ 'name', 'age', 'hair color' ],
-        rows         => [
-            [ 'Fred Flinstone',  2000000, 'black' ],
-            [ 'Wilma Flinstone', 1999995, 'red' ],
+        max_width      => 80,    # Defaults to terminal size
+        pad            => 4,     # Extra padding between table and max-width (defaults to 4)
+        allow_overflow => 0,     # Default is 0, when off an exception will be thrown if the table is too big
+        collapse       => 1,     # Do not show empty columns
+
+        header => ['name', 'age', 'hair color'],
+        rows   => [
+            ['Fred Flintstone',  2000000, 'black'],
+            ['Wilma Flintstone', 1999995, 'red'],
             ...
         ],
     );
@@ -273,13 +286,13 @@ wrong. This module is able to generic format rows of data into tables.
 
 This prints a table like this:
 
-    +-----------------+---------+------------+
-    | name            | age     | hair color |
-    +-----------------+---------+------------+
-    | Fred Flinstone  | 2000000 | black      |
-    | Wilma Flinstone | 1999995 | red        |
-    | ...             | ...     | ...        |
-    +-----------------+---------+------------+
+    +------------------+---------+------------+
+    | name             | age     | hair color |
+    +------------------+---------+------------+
+    | Fred Flintstone  | 2000000 | black      |
+    | Wilma Flintstone | 1999995 | red        |
+    | ...              | ...     | ...        |
+    +------------------+---------+------------+
 
 =head1 INTERFACE
 
@@ -292,8 +305,8 @@ This prints a table like this:
 
 =item header => [ ... ]
 
-If you want a header specify it here. This takes an arrayref with each columns
-heading.
+If you want a header specify it here.
+This takes an arrayref with each columns heading.
 
 =item rows => [ [...], [...], ... ]
 
@@ -310,6 +323,20 @@ Set the maximum width of the table, the table may not be this big, but it will
 be no bigger. If none is specified it will attempt to find the width of your
 terminal and use that, otherwise it falls back to the terminal width or C<80>.
 
+=item pad => $num
+
+Defaults to C<4>, extra padding for row width calculations.
+Default is for legacy support.
+Set this to C<0> to turn padding off.
+
+=item allow_overflow => $bool
+
+Defaults to C<0>. If this is off then an exception will be thrown if the table
+cannot be made to fit inside the max-width. If this is set to C<1> then the
+table will be rendered anyway, larger than max-width, if it is not possible
+to stay within the max-width. In other words this turns max-width from a
+hard-limit to a soft recommendation.
+
 =item sanitize => $bool
 
 This will sanitize all the data in the table such that newlines, control
@@ -317,7 +344,7 @@ characters, and all whitespace except for ASCII 20 C<' '> are replaced with
 escape sequences. This prevents newlines, tabs, and similar whitespace from
 disrupting the table.
 
-B<Note:> newlines are marked as '\n', but a newline is also inserted into the
+B<Note:> newlines are marked as C<\n>, but a newline is also inserted into the
 data so that it typically displays in a way that is useful to humans.
 
 Example:
@@ -394,8 +421,8 @@ will be anomalies in the table:
 
 =head1 SOURCE
 
-The source code repository for Term-Table can be found at
-F<http://github.com/exodist/Term-Table/>.
+The source code repository for C<Term-Table> can be found at
+L<https://github.com/exodist/Term-Table/>.
 
 =head1 MAINTAINERS
 
@@ -420,6 +447,6 @@ Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<https://dev.perl.org/licenses/>
 
 =cut
