@@ -2,7 +2,7 @@ package Term::Table::Cell;
 use strict;
 use warnings;
 
-our $VERSION = '0.009'; # TRIAL
+our $VERSION = '0.026'; # TRIAL
 
 use Term::Table::LineBreak();
 use Term::Table::Util qw/uni_length/;
@@ -34,7 +34,7 @@ sub init {
 sub char_id {
     my $class = shift;
     my ($char) = @_;
-    return "\\N{U+" . sprintf("\%X", ord($char)) . "}";
+    return "\\N{U+" . sprintf("\%X", utf8::native_to_unicode(ord($char))) . "}";
 }
 
 sub show_char {
